@@ -859,6 +859,26 @@ test_key_remove (void)
   g_key_file_free (keyfile);
 }
 
+/* http://bugzilla.gnome.org/show_bug.cgi?id=316309 */
+static void
+test_groups (void)
+{
+  GKeyFile *keyfile;
+
+  const gchar *data = 
+    "[1]\n"
+    "key1=123\n"
+    "[2]\n"
+    "key2=123\n";
+  
+  keyfile = load_data (data, 0);
+
+  check_string_value (keyfile, "1", "key1", "123");
+  check_string_value (keyfile, "2", "key2", "123");
+
+  g_key_file_free (keyfile);  
+}
+
 
 int
 main (int argc, char *argv[])
@@ -874,6 +894,7 @@ main (int argc, char *argv[])
   test_lists ();
   test_group_remove ();
   test_key_remove ();
+  test_groups ();
   
   return 0;
 }
