@@ -120,17 +120,19 @@ from_uri_tests[] = {
    */
   { "file://localhost/etc", "/etc", NULL},
   { "file://localhost/etc/%23%25%20file", "/etc/#% file", NULL},
+  { "file://localhost/\xE5\xE4\xF6", "/\xe5\xe4\xf6", NULL},
+  { "file://localhost/%E5%E4%F6", "/\xe5\xe4\xf6", NULL},
 #else
   { "file://localhost/etc", "/etc", "localhost"},
   { "file://localhost/etc/%23%25%20file", "/etc/#% file", "localhost"},
+  { "file://localhost/\xE5\xE4\xF6", "/\xe5\xe4\xf6", "localhost"},
+  { "file://localhost/%E5%E4%F6", "/\xe5\xe4\xf6", "localhost"},
 #endif
   { "file://otherhost/etc", "/etc", "otherhost"},
   { "file://otherhost/etc/%23%25%20file", "/etc/#% file", "otherhost"},
   { "file://%C3%B6%C3%A4%C3%A5/etc", NULL, NULL, G_CONVERT_ERROR_BAD_URI},
   { "file:////etc/%C3%B6%C3%C3%C3%A5", "//etc/\xc3\xb6\xc3\xc3\xc3\xa5", NULL},
-  { "file://localhost/\xE5\xE4\xF6", "/\xe5\xe4\xf6", "localhost"},
   { "file://\xE5\xE4\xF6/etc", NULL, NULL, G_CONVERT_ERROR_BAD_URI},
-  { "file://localhost/%E5%E4%F6", "/\xe5\xe4\xf6", "localhost"},
   { "file://%E5%E4%F6/etc", NULL, NULL, G_CONVERT_ERROR_BAD_URI},
   { "file:///some/file#bad", NULL, NULL, G_CONVERT_ERROR_BAD_URI},
   { "file://some", NULL, NULL, G_CONVERT_ERROR_BAD_URI},
@@ -219,9 +221,6 @@ run_to_uri_tests (void)
 	    g_print ("Error message: %s\n", error->message);
 	  any_failed = TRUE;
 	}
-      
-      /* Give some output */
-      g_print (".");
     }
 }
 
@@ -303,9 +302,6 @@ run_from_uri_tests (void)
 	      any_failed = TRUE;
 	    }
 	}
-      
-      /* Give some output */
-      g_print (".");
     }
 }
 
@@ -315,6 +311,42 @@ safe_strcmp (const gchar *a, const gchar *b)
   return strcmp (a ? a : "", b ? b : "");
 }
 
+static gint
+safe_strcmp_filename (const gchar *a, const gchar *b)
+{
+#ifndef G_OS_WIN32
+  return safe_strcmp (a, b);
+#else
+  if (!a || !b)
+    return safe_strcmp (a, b);
+  else
+    {
+      while (*a && *b)
+	{
+	  if ((G_IS_DIR_SEPARATOR (*a) && G_IS_DIR_SEPARATOR (*b)) ||
+	      *a == *b)
+	    a++, b++;
+	  else
+	    return (*a - *b);
+	}
+      return (*a - *b);
+    }
+#endif
+}
+
+static gint
+safe_strcmp_hostname (const gchar *a, const gchar *b)
+{
+#ifndef G_OS_WIN32
+  return safe_strcmp (a, b);
+#else
+  if (safe_strcmp (a, "localhost") == 0 && b == NULL)
+    return 0;
+  else
+    return safe_strcmp (a, b);
+#endif
+}
+
 static void
 run_roundtrip_tests (void)
 {
@@ -350,7 +382,7 @@ run_roundtrip_tests (void)
 	  continue;
 	}
 
-      if (safe_strcmp (to_uri_tests[i].filename, res))
+      if (safe_strcmp_filename (to_uri_tests[i].filename, res))
 	{
 	  g_print ("roundtrip test %d failed, filename modified: "
 		   " expected \"%s\", but got \"%s\"\n",
@@ -358,18 +390,14 @@ run_roundtrip_tests (void)
 	  any_failed = TRUE;
 	}
 
-      if (safe_strcmp (to_uri_tests[i].hostname, hostname))
+      if (safe_strcmp_hostname (to_uri_tests[i].hostname, hostname))
 	{
 	  g_print ("roundtrip test %d failed, hostname modified: "
 		     " expected \"%s\", but got \"%s\"\n",
 		   i, to_uri_tests[i].hostname, hostname);
 	  any_failed = TRUE;
 	}
-
-      /* Give some output */
-      g_print (".");
     }
-  g_print ("\n");
 }
 
 static void
